#########################
# Main file to run code #
#########################

# Housekeeping
exit()
clearconsole()

# Load packages
using DataFrames, LinearAlgebra, Optim, Parameters, PrettyTables, Plots, Roots

# Load functions
include("Functions/f_Functions.jl")

# Call exogenous parameters
Params = SetParams()

## Calculate Model's Predictions

# 1970-74
h_model_7074, error_7074 = ComputeHours(Params.α,Params.τ_7074,Params.CtoO_7074,Params.h_7074,Params)
# 1993-96
h_model_9396, error_9396 = ComputeHours(Params.α,Params.τ_9396,Params.CtoO_9396,Params.h_9396,Params)
# Euclidean norm for the prediction error over both periods
norm_error = norm([error_7074, error_9396])
# Summary table
Table = OutputTable(h_model_7074,h_model_9396,error_7074,error_9396,norm_error,Params)

## Plots

# Figure 1 (1993-96)
heading = "Fit of Model: Prescott's α, 1993 to 1996"
plot3 = MakeFig(Params.h_9396, h_model_9396, heading)
# Figure 2 (1970-74)
heading = "Fit of Model: Prescott's α, 1970 to 1974"
plot4 = MakeFig(Params.h_7074, h_model_7074, heading)

## Print stuff
println("Results using the alpha that fits the best. Two approaches are taken:")
println("a: solve the first-order condition from least squares problem")
println("b: solve the least squares minimization problem")

## Calculate the optimal value for α

# Call nonlinear equation solver to compute least squares problem
α = find_zero(FOC, Params.α)
# Check foc is close to zero
if abs(FOC(α)) >= 0.0000001
    print("Solution not found")
end
# Print stuff
println("α (from first-order condition) = $α")

# Calculate Model's Predictions--by using the first-order condition for
# for the least squares problem
h_model_7074, error_7074 = ComputeHours(α,Params.τ_9396,Params.CtoO_9396,Params.h_9396,Params)
h_model_9396, error_9396 = ComputeHours(α,Params.τ_9396,Params.CtoO_9396,Params.h_9396,Params)
# Euclidean norm for the prediction error over both periods
norm_error = norm([error_7074, error_9396])
# Summary table
Table = OutputTable(h_model_7074,h_model_9396,error_7074,error_9396,norm_error,Params)

## Plots to show fit

# Figure 3 (1993-96)
heading = "Fit of Model: Fitted α, 1993 to 1996"
plot3 = MakeFig(Params.h_9396, h_model_9396, heading)
# Figure 4 (1970-74)
heading = "Fit of Model: Fitted α, 1970 to 1974"
plot4 = MakeFig(Params.h_7074, h_model_7074, heading)

## Calculate Model's Predictions--by minimizing the sum of the squares

# Lower bound
x_lb = 1.0
# Upper bound
x_ub = 2.0
# Call minimization routine
results = Optim.optimize(SumOfSquares,x_lb,x_ub)
α = results.minimizer
# Print stuff
println("α (by minimizing the sum of the squares) = $α")
